==> kadaster-gds2-1.4-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandenlijstgbresultaat/afgifte/v20130701/AfgifteGBType.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandenlijstgbresultaat.afgifte.v20130701;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import nl.kadaster.schemas.gds2.afgifte_bestandenlijstresultaat.afgifte.v20130701.AfgifteType;
import nl.logius.digikoppeling.gb._2010._10.ExternalDataReference;


/**
 * <p>Java class for AfgifteGBType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="AfgifteGBType">
 *   &lt;complexContent>
 *     &lt;extension base="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstresultaat/afgifte/v20130701}AfgifteType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.logius.nl/digikoppeling/gb/2010/10}digikoppeling-external-datareferences"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "AfgifteGBType", propOrder = {
    "digikoppelingExternalDatareferences"
})
public class AfgifteGBType
    extends AfgifteType
{

    @XmlElement(name = "digikoppeling-external-datareferences", namespace = "http://www.logius.nl/digikoppeling/gb/2010/10", required = true)
    protected ExternalDataReference digikoppelingExternalDatareferences;

    /**
     * Gets the value of the digikoppelingExternalDatareferences property.
     * 
     * @return
     *     possible object is
     *     {@link ExternalDataReference }
     *     
     */
    public ExternalDataReference getDigikoppelingExternalDatareferences() {
        return digikoppelingExternalDatareferences;
    }

    /**
     * Sets the value of the digikoppelingExternalDatareferences property.
     * 
     * @param value
     *     allowed object is
     *     {@link ExternalDataReference }
     *     
     */
    public void setDigikoppelingExternalDatareferences(ExternalDataReference value) {
        this.digikoppelingExternalDatareferences = value;
    }

}

==> kadaster-gds2-2.0-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandenlijstgbresultaat/afgifte/v20130701/AfgifteGBType.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandenlijstgbresultaat.afgifte.v20130701;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import nl.kadaster.schemas.gds2.afgifte_bestandenlijstresultaat.afgifte.v20130701.AfgifteType;
import nl.logius.digikoppeling.gb._2010._10.ExternalDataReference;


/**
 * <p>Java class for AfgifteGBType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="AfgifteGBType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstresultaat/afgifte/v20130701}AfgifteType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{http://www.logius.nl/digikoppeling/gb/2010/10}digikoppeling-external-datareferences"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "AfgifteGBType", propOrder = {
    "digikoppelingExternalDatareferences"
})
public class AfgifteGBType
    extends AfgifteType
{

    @XmlElement(name = "digikoppeling-external-datareferences", namespace = "http://www.logius.nl/digikoppeling/gb/2010/10", required = true)
    protected ExternalDataReference digikoppelingExternalDatareferences;

    /**
     * Gets the value of the digikoppelingExternalDatareferences property.
     * 
     * @return
     *     possible object is
     *     {@link ExternalDataReference }
     *     
     */
    public ExternalDataReference getDigikoppelingExternalDatareferences() {
        return digikoppelingExternalDatareferences;
    }

    /**
     * Sets the value of the digikoppelingExternalDatareferences property.
     * 
     * @param value
     *     allowed object is
     *     {@link ExternalDataReference }
     *     
     */
    public void setDigikoppelingExternalDatareferences(ExternalDataReference value) {
        this.digikoppelingExternalDatareferences = value;
    }

}
